@@ -118,7 +118,7 @@ def get_page_links(domain_url, url, allowed_domains, file_size=1024, sleep_time=
     """ get_page_links() will return a list of all of the link on a html page that is passed.
     """
 
-    #log( "Getting page links for '{0}' ...".format(url) )
+    log( "get_page_links(): Getting page links for '{0}' ...".format(url) )
 
     success = False
     links = []
@@ -161,6 +161,8 @@ def get_page_links(domain_url, url, allowed_domains, file_size=1024, sleep_time=
                 tags = soup.find_all(tag_type)
                 for tag in tags:
                 
+                    log( 'get_page_links(): working on tag: {0}'.format(tag) )
+
                     if len(tag.contents) >= 1:
                         link_text = unicode(tag.string).strip()
                     else:
